@@ -12,10 +12,11 @@ use ross_config::config::Config;
 use ross_protocol::event::event_code::*;
 
 use crate::error::{ErrorKind, Expectation, ParserError};
-use crate::literal::{literal_or_constant, Literal};
+use crate::literal::{literal, literal_or_constant, Literal};
 use crate::statement::const_statement::const_statement;
 use crate::statement::do_statement::do_statement;
 use crate::statement::let_statement::let_statement;
+use crate::statement::peripheral_statement::peripheral_statement;
 use crate::statement::send_statement::send_statement;
 use crate::symbol::{close_parenthesis, comma, open_parenthesis};
 
@@ -29,6 +30,7 @@ pub struct Parser {}
 
 impl Parser {
     pub fn parse<'a, 'b>(text: &'a str) -> Result<Config, ParserError<String>> {
+        let mut peripherals = BTreeMap::new();
         let mut initial_state = BTreeMap::new();
         let mut constants = BTreeMap::new();
         let mut event_processors = vec![];
@@ -41,6 +43,17 @@ impl Parser {
         while commentless_text.len() != 0 {
             let mut errors = vec![];
 
+            match preceded(multispace0, peripheral_statement)(commentless_text) {
+                Ok((input, (index, peripheral))) => {
+                    peripherals.insert(index, peripheral);
+                    commentless_text = input;
+                    continue;
+                }
+                Err(NomErr::Error(err)) => errors.push(err),
+                Err(NomErr::Failure(err)) => return Err(err.into()),
+                _ => {}
+            }
+
             match preceded(multispace0, let_statement)(commentless_text) {
                 Ok((input, (name, value))) => {
                     let initial_state_index = initial_state.len() as u32;
@@ -104,6 +117,7 @@ impl Parser {
         }
 
         Ok(Config {
+            peripherals,
             initial_state,
             event_processors,
         })
@@ -203,7 +217,7 @@ pub fn dec1(text: &str) -> IResult<&str, &str, ParserError<&str>> {
     )
 }
 
-pub fn argument0<'a>(
+pub fn argument_or_constant0<'a>(
     constants: &'a BTreeMap<&str, Literal>,
 ) -> impl FnMut(&str) -> IResult<&str, Vec<Literal>, ParserError<&str>> + 'a {
     move |text| {
@@ -218,6 +232,14 @@ pub fn argument0<'a>(
     }
 }
 
+pub fn argument0(text: &str) -> IResult<&str, Vec<Literal>, ParserError<&str>> {
+    delimited(
+        terminated(open_parenthesis, multispace0),
+        separated_list0(comma, delimited(multispace0, literal, multispace0)),
+        close_parenthesis,
+    )(text)
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
@@ -367,10 +389,62 @@ mod tests {
     }
 
     #[test]
-    fn argument0_two_arguments_test() {
+    fn argument_or_constant0_two_arguments_test() {
         let constants = BTreeMap::new();
         assert_matches!(
-            argument0(&constants)("(0xab~u16, false)"),
+            argument_or_constant0(&constants)("(0xab~u16, false)"),
+            Ok((input, arguments)) => {
+                assert_eq!(input, "");
+                assert_eq!(arguments, vec![Literal::U16(0xab), Literal::Bool(false)]);
+            }
+        );
+    }
+
+    #[test]
+    fn argument_or_constant0_one_argument_test() {
+        let constants = BTreeMap::new();
+        assert_matches!(
+            argument_or_constant0(&constants)("(0xab~u16)"),
+            Ok((input, arguments)) => {
+                assert_eq!(input, "");
+                assert_eq!(arguments, vec![Literal::U16(0xab)]);
+            }
+        );
+    }
+
+    #[test]
+    fn argument_or_constant0_no_arguments_test() {
+        let constants = BTreeMap::new();
+        assert_matches!(
+            argument_or_constant0(&constants)("(  )"),
+            Ok((input, arguments)) => {
+                assert_eq!(input, "");
+                assert_eq!(arguments, vec![]);
+            }
+        );
+    }
+
+    #[test]
+    fn argument_or_constant0_empty_test() {
+        let constants = BTreeMap::new();
+        assert_matches!(
+            argument_or_constant0(&constants)(""),
+            Err(NomErr::Error(ParserError::Base {
+                location,
+                kind,
+                child,
+            })) => {
+                assert_matches!(location, "");
+                assert_matches!(kind, ErrorKind::Expected(Expectation::Symbol('(')));
+                assert_matches!(child, None);
+            }
+        );
+    }
+
+    #[test]
+    fn argument0_two_arguments_test() {
+        assert_matches!(
+            argument0("(0xab~u16, false)"),
             Ok((input, arguments)) => {
                 assert_eq!(input, "");
                 assert_eq!(arguments, vec![Literal::U16(0xab), Literal::Bool(false)]);
@@ -380,9 +454,8 @@ mod tests {
 
     #[test]
     fn argument0_one_argument_test() {
-        let constants = BTreeMap::new();
         assert_matches!(
-            argument0(&constants)("(0xab~u16)"),
+            argument0("(0xab~u16)"),
             Ok((input, arguments)) => {
                 assert_eq!(input, "");
                 assert_eq!(arguments, vec![Literal::U16(0xab)]);
@@ -392,9 +465,8 @@ mod tests {
 
     #[test]
     fn argument0_no_arguments_test() {
-        let constants = BTreeMap::new();
         assert_matches!(
-            argument0(&constants)("(  )"),
+            argument0("(  )"),
             Ok((input, arguments)) => {
                 assert_eq!(input, "");
                 assert_eq!(arguments, vec![]);
@@ -404,9 +476,8 @@ mod tests {
 
     #[test]
     fn argument0_empty_test() {
-        let constants = BTreeMap::new();
         assert_matches!(
-            argument0(&constants)(""),
+            argument0(""),
             Err(NomErr::Error(ParserError::Base {
                 location,
                 kind,
